window.addEventListener('load', () => {
    const canvas = document.getElementById('gameCanvas');
    const ctx = canvas.getContext('2d');

    let birdX = 50;
    let birdY = canvas.height / 2;
    let gravity = 1;
    let velocity = 0;
    let pipeGap = 100;
    let pipeFrequency = 120;
    let pipes = [];
    let score = 0;
    let gameOver = false;

    function drawBird() {
        ctx.beginPath();
        ctx.arc(birdX, birdY, 20, 0, Math.PI * 2);
        ctx.fillStyle = 'red';
        ctx.fill();
        ctx.closePath();
    }

    function drawPipes() {
        for (let i = 0; i < pipes.length; i++) {
            let pipe = pipes[i];
            ctx.beginPath();
            ctx.rect(pipe.x, 0, pipe.width, pipe.topHeight);
            ctx.rect(pipe.x, pipe.bottomY, pipe.width, pipe.bottomHeight);
            ctx.fillStyle = 'green';
            ctx.fill();
            ctx.closePath();
        }
    }

    function updateBird() {
        velocity += gravity;
        birdY += velocity;
    }

    function updatePipes() {
        for (let i = 0; i < pipes.length; i++) {
            let pipe = pipes[i];
            pipe.x -= 2;

            if (pipe.x + pipe.width < 0) {
                pipes.splice(i, 1);
                i--;
            }

            if (birdX + 20 > pipe.x && birdX - 20 < pipe.x + pipe.width) {
                if (birdY - 20 < pipe.topHeight || birdY + 20 > pipe.bottomY) {
                    gameOver = true;
                }
            }

            if (pipe.x + pipe.width === birdX - 20) {
                score++;
            }
        }

        if (pipes.length === 0 || pipes[pipes.length - 1].x + pipeFrequency < canvas.width) {
            let topHeight = Math.random() * (canvas.height - pipeGap);
            let bottomHeight = canvas.height - pipeGap - topHeight;
            let pipe = {
                x: canvas.width,
                topHeight: topHeight,
                bottomY: topHeight

 + pipeGap,
                bottomHeight: bottomHeight,
                width: 50
            };
            pipes.push(pipe);
        }
    }

    function drawScore() {
        ctx.font = '24px Arial';
        ctx.fillStyle = 'black';
        ctx.fillText('Score: ' + score, 10, 30);
    }

    function drawGameOver() {
        ctx.font = '48px Arial';
        ctx.fillStyle = 'black';
        ctx.fillText('Game Over', canvas.width / 2 - 120, canvas.height / 2);
    }

    function draw() {
        ctx.clearRect(0, 0, canvas.width, canvas.height);

        if (!gameOver) {
            drawBird();
            drawPipes();
            updateBird();
            updatePipes();
            drawScore();
            requestAnimationFrame(draw);
        } else {
            drawGameOver();
        }
    }

    document.addEventListener('keydown', (e) => {
        if (e.code === 'Space') {
            velocity = -12;
        }
    });

    draw();
});
